@@ -1,8 +1,7 @@
-import { FC } from 'react';
-
-import { ComponentHealthState } from './types';
+import { type FC } from 'react';
 
 import styles from './HealthLabel.module.css';
+import { ComponentHealthState } from './types';
 
 interface HealthLabelProps {
   health: ComponentHealthState;
