@@ -1,6 +1,6 @@
-import { FC, ReactNode } from 'react';
-import { IconProp } from '@fortawesome/fontawesome-svg-core';
+import { type IconProp } from '@fortawesome/fontawesome-svg-core';
 import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
+import { type FC, type ReactNode } from 'react';
 
 import styles from './Page.module.css';
 
